NMsimCheckMod: Check a simulation control streams for things that can cause...

View source: R/NMsimCheckMod.R

NMsimCheckModR Documentation

Check a simulation control streams for things that can cause trouble in NMsim

Description

Check a simulation control streams for things that can cause trouble in NMsim

Usage

NMsimCheckMod(file.mod, lines)

Arguments

file.mod

A control stream to check

lines

The control stream as text lines. Only use of of 'file.mod' and 'lines'.


NMsim documentation built on March 19, 2026, 9:07 a.m.