View source: R/prioritizePaths.R
| prioritizePaths | R Documentation |
When using scripts on different systems, the Nonmem path may change from run to run. With this function you can specify a few paths, and it will return the one that works on the system in use.
prioritizePaths(paths, must.work = FALSE)
paths |
vector of file paths. Typically to Nonmem executables. |
must.work |
If TRUE, an error is thrown if no paths are valid. |
library(NMdata)
NMdataConf(path.nonmem = prioritizePaths(c(
"/opt/NONMEM/nm75/run/nmfe75",
"C:/nm75g64/run/nmfe75.bat")
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.